@@ -2,7 +2,7 @@
 
 source $(dirname $0)/test.inc.sh
 
-pocount -h
+python $PYTHON_ARGS $(which pocount) -h
 start_checks
 has_stdout
 end_checks
