@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -17,17 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
 
 import difflib
 import os
 import os.path as path
-import six
 import sys
 import zipfile
 
 from lxml import etree
 
+
 # get directory of this test
 dir = os.path.dirname(os.path.abspath(__file__))
 # get top-level directory (moral equivalent of ../..)
@@ -35,8 +33,8 @@ dir = os.path.dirname(os.path.dirname(dir))
 # load python modules from top-level
 sys.path.insert(0, dir)
 
-from translate.convert import odf2xliff, xliff2odf
-from translate.storage import factory, xliff
+from translate.convert import odf2xliff, xliff2odf  # isort:skip
+from translate.storage import factory, xliff  # isort:skip
 
 
 def setup_module(module):
@@ -45,13 +43,13 @@ def setup_module(module):
 
 def args(src, tgt, **kwargs):
     arg_list = []
-    arg_list.extend([u'--errorlevel=traceback', src, tgt])
-    for flag, value in six.iteritems(kwargs):
-        value = six.text_type(value)
+    arg_list.extend(["--errorlevel=traceback", src, tgt])
+    for flag, value in kwargs.items():
+        value = str(value)
         if len(flag) == 1:
-            arg_list.append(u'-%s' % flag)
+            arg_list.append("-%s" % flag)
         else:
-            arg_list.append(u'--%s' % flag)
+            arg_list.append("--%s" % flag)
         if value is not None:
             arg_list.append(value)
     return arg_list
@@ -65,24 +63,24 @@ xliff.xlifffile.__eq__ = xliff___eq__
 
 
 def print_diff(store1, store2):
-    store1_lines = bytes(store1).decode(store1.encoding).split('\n')
-    store2_lines = bytes(store2).decode(store2.encoding).split('\n')
+    store1_lines = bytes(store1).decode(store1.encoding).split("\n")
+    store2_lines = bytes(store2).decode(store2.encoding).split("\n")
     for line in difflib.unified_diff(store1_lines, store2_lines):
         print(line)
 
 
-SOURCE_ODF = u'test_2.odt'
-REFERENCE_XLF = u'test_2-test_odf2xliff-reference.xlf'
-GENERATED_XLF_ITOOLS = u'test_2-test_odf2xliff-itools.xlf'
-GENERATED_XLF_TOOLKIT = u'test_2-test_odf2xliff-toolkit.xlf'
+SOURCE_ODF = "test_2.odt"
+REFERENCE_XLF = "test_2-test_odf2xliff-reference.xlf"
+GENERATED_XLF_ITOOLS = "test_2-test_odf2xliff-itools.xlf"
+GENERATED_XLF_TOOLKIT = "test_2-test_odf2xliff-toolkit.xlf"
 
-TARGET_XLF = u'test_2-test_roundtrip.xlf'
-REFERENCE_ODF = u'test_2.odt'
-GENERATED_ODF = u'test_2-test_roundtrip-generated.odt'
+TARGET_XLF = "test_2-test_roundtrip.xlf"
+REFERENCE_ODF = "test_2.odt"
+GENERATED_ODF = "test_2-test_roundtrip-generated.odt"
 
-SOURCE_ODF_INLINE = u'test_inline.odt'
-REFERENCE_XLF_INLINE = u'test_inline-test_odf2xliff_inline-reference.xlf'
-GENERATED_XLF_TOOLKIT_INLINE = u'test_inline-test_odf2xliff_inline-toolkit.xlf'
+SOURCE_ODF_INLINE = "test_inline.odt"
+REFERENCE_XLF_INLINE = "test_inline-test_odf2xliff_inline-reference.xlf"
+GENERATED_XLF_TOOLKIT_INLINE = "test_inline-test_odf2xliff_inline-toolkit.xlf"
 
 
 def test_odf2xliff():
@@ -100,12 +98,12 @@ def test_odf2xliff():
 
 
 def is_content_file(filename):
-    return filename in (u'content.xml', u'meta.xml', u'styles.xml')
+    return filename in ("content.xml", "meta.xml", "styles.xml")
 
 
-class ODF(object):
+class ODF:
 
-    encoding = 'utf-8'
+    encoding = "utf-8"
 
     def __init__(self, filename):
         self.odf = zipfile.ZipFile(filename)
@@ -114,7 +112,9 @@ class ODF(object):
         return self.odf.read(filename)
 
     def _get_doc_root(self, filename):
-        return etree.tostring(etree.fromstring(self._get_data(filename)), pretty_print=True)
+        return etree.tostring(
+            etree.fromstring(self._get_data(filename)), pretty_print=True
+        )
 
     def __eq__(self, other):
         if other is None:
@@ -143,7 +143,7 @@ class ODF(object):
         return self.serialize()
 
     def serialize(self):
-        return self._get_doc_root('content.xml')
+        return self._get_doc_root("content.xml")
 
 
 def test_roundtrip():
