@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
 #
@@ -23,8 +22,7 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
-from translate.convert import (convert, dtd2po, mozfunny2prop, mozlang2po,
-                               prop2po)
+from translate.convert import convert, dtd2po, mozfunny2prop, mozlang2po, prop2po
 
 
 def main(argv=None):
@@ -40,7 +38,7 @@ def main(argv=None):
         ("it", mozfunny2prop.it2po),
         ("ini", mozfunny2prop.ini2po),
         ("inc", mozfunny2prop.inc2po),
-        ("lang", mozlang2po.convertlang),
+        ("lang", mozlang2po.run_converter),
     ]
     for format, converter in converters:
         formats[(format, format)] = (format + ".po", converter)
@@ -48,18 +46,19 @@ def main(argv=None):
     # handle search and replace
     replacer = convert.Replacer("en-US", "${locale}")
     for replaceformat in ("js", "rdf", "manifest"):
-        formats[(None, replaceformat)] = (replaceformat,
-                                          replacer.searchreplacetemplate)
-        formats[(replaceformat, replaceformat)] = (replaceformat,
-                                                   replacer.searchreplaceinput)
+        formats[(None, replaceformat)] = (replaceformat, replacer.searchreplacetemplate)
+        formats[(replaceformat, replaceformat)] = (
+            replaceformat,
+            replacer.searchreplaceinput,
+        )
         formats[replaceformat] = (replaceformat, replacer.searchreplaceinput)
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         usepots=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, usepots=True, description=__doc__
+    )
     parser.add_duplicates_option()
     parser.passthrough.append("pot")
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
