@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
 #
@@ -29,29 +27,54 @@ from translate.storage import factory, jsonl10n
 
 
 class rejson:
-
     def __init__(self, templatefile, inputstore):
         self.templatefile = templatefile
         self.templatestore = jsonl10n.JsonFile(templatefile)
+        self.ouputstore = jsonl10n.JsonFile()
         self.inputstore = inputstore
 
-    def convertstore(self, includefuzzy=False):
+    def convertstore(self, includefuzzy=False, remove_untranslated=False):
         self.includefuzzy = includefuzzy
+        self.remove_untranslated = remove_untranslated
         self.inputstore.makeindex()
         for unit in self.templatestore.units:
             inputunit = self.inputstore.locationindex.get(unit.getid())
+            skip_unit = self.remove_untranslated and (
+                inputunit is None or inputunit.isfuzzy() or not inputunit.istranslated()
+            )
+            if skip_unit:
+                continue
             if inputunit is not None:
-                if inputunit.isfuzzy() and not self.includefuzzy:
-                    unit.target = unit.source
+                if inputunit.isfuzzy():
+                    if self.includefuzzy:
+                        # inputunit.istranslated() is always False now,
+                        # because inputunit.isfuzzy() is True.
+                        # So we need to check if inputunit.target is truthy.
+                        if inputunit.target:
+                            unit.target = inputunit.target
+                        else:
+                            unit.target = unit.source
+                    else:
+                        unit.target = unit.source
                 else:
-                    unit.target = inputunit.target
+                    if inputunit.istranslated():
+                        unit.target = inputunit.target
+                    else:
+                        unit.target = unit.source
             else:
                 unit.target = unit.source
-        return str(self.templatestore)
+            self.ouputstore.addunit(unit)
+        return bytes(self.ouputstore)
 
 
-def convertjson(inputfile, outputfile, templatefile, includefuzzy=False,
-                outputthreshold=None):
+def convertjson(
+    inputfile,
+    outputfile,
+    templatefile,
+    includefuzzy=False,
+    outputthreshold=None,
+    remove_untranslated=False,
+):
     inputstore = factory.getobject(inputfile)
 
     if not convert.should_output_store(inputstore, outputthreshold):
@@ -61,7 +84,7 @@ def convertjson(inputfile, outputfile, templatefile, includefuzzy=False,
         raise ValueError("Must have template file for JSON files")
 
     convertor = rejson(templatefile, inputstore)
-    outputstring = convertor.convertstore(includefuzzy)
+    outputstring = convertor.convertstore(includefuzzy, remove_untranslated)
     outputfile.write(outputstring)
     return True
 
@@ -71,12 +94,14 @@ def main(argv=None):
     formats = {
         ("po", "json"): ("json", convertjson),
     }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, description=__doc__
+    )
     parser.add_threshold_option()
     parser.add_fuzzy_option()
+    parser.add_remove_untranslated_option()
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
