@@ -53,7 +53,8 @@ class po2resx:
 
         return bytes(self.templatestore)
 
-    def addcomments(self, inputunit, unit):
+    @staticmethod
+    def addcomments(inputunit, unit):
         comments = []
 
         # Handle #. automatic comments
@@ -67,14 +68,15 @@ class po2resx:
 
         # Join automatic and translator comments with a newline as per
         # convention.
-        combocomment = '\n'.join(comments)
+        combocomment = "\n".join(comments)
 
         if combocomment:
             unit.addnote(combocomment)
 
 
-def convertresx(inputfile, outputfile, templatefile, includefuzzy=False,
-                outputthreshold=None):
+def convertresx(
+    inputfile, outputfile, templatefile, includefuzzy=False, outputthreshold=None
+):
 
     inputstore = factory.getobject(inputfile)
 
@@ -92,11 +94,12 @@ def main(argv=None):
     formats = {
         ("po", "resx"): ("resx", convertresx),
     }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, description=__doc__
+    )
     parser.add_fuzzy_option()
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
