@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2014 Zuza Software Foundation
 #
@@ -24,7 +23,6 @@ for examples and usage instructions.
 """
 
 import logging
-import six
 
 from translate.convert.accesskey import UnitMixer
 from translate.storage import po, properties
@@ -37,18 +35,15 @@ class DiscardUnit(ValueError):
     pass
 
 
-class prop2po(object):
-    """convert a .properties file to a .po file for handling the translation.
-    """
+class prop2po:
+    """convert a .properties file to a .po file for handling the translation."""
 
-    def __init__(self, personality="java", blankmsgstr=False,
-                 duplicatestyle="msgctxt"):
+    def __init__(self, personality="java", blankmsgstr=False, duplicatestyle="msgctxt"):
         self.personality = personality
         self.blankmsgstr = blankmsgstr
         self.duplicatestyle = duplicatestyle
         self.mixedkeys = {}
-        self.mixer = UnitMixer(properties.labelsuffixes,
-                               properties.accesskeysuffixes)
+        self.mixer = UnitMixer(properties.labelsuffixes, properties.accesskeysuffixes)
 
     def convertstore(self, thepropfile):
         """converts a .properties file to a .po file..."""
@@ -60,8 +55,7 @@ class prop2po(object):
             )
         else:
             targetheader = thetargetfile.header()
-        targetheader.addnote("extracted from %s" % thepropfile.filename,
-                             "developer")
+        targetheader.addnote("extracted from %s" % thepropfile.filename, "developer")
 
         thepropfile.makeindex()
         self.mixedkeys = self.mixer.match_entities(thepropfile.id_index)
@@ -78,18 +72,24 @@ class prop2po(object):
                 waitingcomments.extend(propunit.comments)
             if not appendedheader:
                 if propunit.isblank():
-                    targetheader.addnote("\n".join(waitingcomments).rstrip(),
-                                         "developer", position="prepend")
+                    targetheader.addnote(
+                        "\n".join(waitingcomments).rstrip(),
+                        "developer",
+                        position="prepend",
+                    )
                     waitingcomments = []
                     pounit = None
                 appendedheader = True
             if pounit is not None:
-                pounit.addnote("\n".join(waitingcomments).rstrip(),
-                               "developer", position="prepend")
+                pounit.addnote(
+                    "\n".join(waitingcomments).rstrip(), "developer", position="prepend"
+                )
                 waitingcomments = []
                 thetargetfile.addunit(pounit)
         if self.personality == "gaia":
             thetargetfile = self.fold_gaia_plurals(thetargetfile)
+        elif self.personality == "gwt":
+            thetargetfile = self.fold_gwt_plurals(thetargetfile)
         thetargetfile.removeduplicates(self.duplicatestyle)
         return thetargetfile
 
@@ -103,10 +103,13 @@ class prop2po(object):
             )
         else:
             targetheader = thetargetfile.header()
-        targetheader.addnote("extracted from %s, %s" % (origpropfile.filename, translatedpropfile.filename),
-                             "developer")
+        targetheader.addnote(
+            "extracted from %s, %s"
+            % (origpropfile.filename, translatedpropfile.filename),
+            "developer",
+        )
         origpropfile.makeindex()
-        #TODO: self.mixedkeys is overwritten below, so this is useless:
+        # TODO: self.mixedkeys is overwritten below, so this is useless:
         self.mixedkeys = self.mixer.match_entities(origpropfile.id_index)
         translatedpropfile.makeindex()
         self.mixedkeys = self.mixer.match_entities(translatedpropfile.id_index)
@@ -125,8 +128,11 @@ class prop2po(object):
             # handle the header case specially...
             if not appendedheader:
                 if origprop.isblank():
-                    targetheader.addnote(u"".join(waitingcomments).rstrip(),
-                                         "developer", position="prepend")
+                    targetheader.addnote(
+                        "".join(waitingcomments).rstrip(),
+                        "developer",
+                        position="prepend",
+                    )
                     waitingcomments = []
                     origpo = None
                 appendedheader = True
@@ -136,9 +142,9 @@ class prop2po(object):
                 # Need to check that this comment is not a copy of the
                 # developer comments
                 try:
-                    translatedpo = self.convertpropunit(translatedpropfile,
-                                                        translatedprop,
-                                                        "translator")
+                    translatedpo = self.convertpropunit(
+                        translatedpropfile, translatedprop, "translator"
+                    )
                 except DiscardUnit:
                     continue
             else:
@@ -147,19 +153,118 @@ class prop2po(object):
             if origpo is not None:
                 if translatedpo is not None and not self.blankmsgstr:
                     origpo.target = translatedpo.source
-                origpo.addnote(u"".join(waitingcomments).rstrip(),
-                               "developer", position="prepend")
+                origpo.addnote(
+                    "".join(waitingcomments).rstrip(), "developer", position="prepend"
+                )
                 waitingcomments = []
                 thetargetfile.addunit(origpo)
             elif translatedpo is not None:
-                logger.error("didn't convert original property definition '%s'",
-                             origprop.name)
+                logger.error(
+                    "didn't convert original property definition '%s'", origprop.name
+                )
         if self.personality == "gaia":
             thetargetfile = self.fold_gaia_plurals(thetargetfile)
+        elif self.personality == "gwt":
+            thetargetfile = self.fold_gwt_plurals(thetargetfile)
         thetargetfile.removeduplicates(self.duplicatestyle)
         return thetargetfile
 
-    def fold_gaia_plurals(self, postore):
+    def fold_gwt_plurals(self, postore):
+        """Fold the multiple plural units of a gwt file into a gettext plural."""
+
+        def _append_plural_unit(plural_unit, units):
+            sources = [u.source for u in units]
+            targets = [u.target for u in units]
+            # TODO: only consider the right ones for sources and targets
+            plural_unit.source = sources
+            plural_unit.target = targets
+            plural_unit.addlocation(key)
+
+        # Map GWT variants to cldr names
+        gwt2cldr = {
+            "none": "zero",
+            "one": "one",
+            "two": "two",
+            "few": "few",
+            "many": "many",
+            "": "other",
+        }
+
+        class Variants:
+            def __init__(self, unit):
+                self.unit = unit
+                self.variants = {}
+
+        import re
+
+        from translate.lang import data
+
+        regex = re.compile(r"([^\[\]]*)(?:\[(.*)\])?")
+        names = data.cldr_plural_categories
+        new_store = type(postore)()
+        plurals = {}
+        for unit in postore.units:
+            if not unit.istranslatable():
+                # TODO: reconsider: we could lose header comments here
+                continue
+            string = unit.getlocations()[0]
+            match = regex.match(string)
+            if not match:
+                logger.warn("Invalid key: %s", string)
+                continue
+            key = match.group(1)
+            variant = match.group(2)
+            if key not in plurals:
+                # Generate fake unit for each keys
+                new_unit = new_store.addsourceunit("fish")
+                plurals[key] = Variants(new_unit)
+
+            # No variant => other
+            if not variant:
+                variant = ""
+
+            # Translate gwt variants to cldr names
+            old_variant = variant
+            variant = gwt2cldr.get(variant)
+
+            # Some sanity checks
+            if not variant:
+                raise Exception("Variant invalid: %s" % (old_variant))
+            if variant in plurals[key].variants:
+                logger.warn(
+                    "Override %s[%s]: %s by %s",
+                    key,
+                    variant,
+                    plurals[key].variants[variant],
+                    unit,
+                )
+
+            # Put the unit
+            plurals[key].variants[variant] = unit
+
+        # Rework the set
+        for key, plural in plurals.items():
+            # We should have at least "other" (no variant in GWT)
+            if "other" not in plural.variants:
+                raise Exception("Should have property %s without any variant" % (key))
+            units = []
+            for name in names:
+                if name in plural.variants:
+                    unit = plural.variants[name]
+                    unit.target = unit.source
+                    units.append(unit)
+            # Replace the sources by good ones
+            if "one" in plural.variants and len(units) > 0:
+                units[0].source = plural.variants["one"].source
+            if "other" in plural.variants and len(units) > 1:
+                units[1].source = plural.variants["other"].source
+
+            # Create the plural unit
+            _append_plural_unit(plural.unit, units)
+        return new_store
+
+    @staticmethod
+    def fold_gaia_plurals(postore):
         """Fold the multiple plural units of a gaia file into a gettext plural."""
 
         def _append_plural_unit(store, plurals, plural):
@@ -174,16 +279,16 @@ class prop2po(object):
 
         new_store = type(postore)()
         plurals = {}
-        current_plural = u""
+        current_plural = ""
         for unit in postore.units:
             if not unit.istranslatable():
-                #TODO: reconsider: we could lose header comments here
+                # TODO: reconsider: we could lose header comments here
                 continue
-            if u"plural(n)" in unit.source:
+            if "plural(n)" in unit.source:
                 if current_plural:
                     # End of a set of plural units
                     _append_plural_unit(new_store, plurals, current_plural)
-                    current_plural = u""
+                    current_plural = ""
                 # start of a set of plural units
                 location = unit.getlocations()[0]
                 current_plural = location
@@ -194,28 +299,30 @@ class prop2po(object):
                 location = unit.getlocations()[0]
                 if current_plural and location.startswith(current_plural):
                     plurals[current_plural].append(unit)
-                    if '[zero]' not in location:
+                    if "[zero]" not in location:
                         # We want to keep [zero] cases separately translatable
                         continue
                 elif current_plural:
                     # End of a set of plural units
                     _append_plural_unit(new_store, plurals, current_plural)
-                    current_plural = u""
+                    current_plural = ""
 
                 new_store.addunit(unit)
 
         if current_plural:
             # The file ended with a set of plural units
             _append_plural_unit(new_store, plurals, current_plural)
-            current_plural = u""
+            current_plural = ""
 
         # if everything went well, there should be nothing left in plurals
         if len(plurals) != 0:
-            logger.warning("Not all plural units converted correctly:" +
-                           "\n".join(plurals.keys()))
+            logger.warning(
+                "Not all plural units converted correctly:" + "\n".join(plurals)
+            )
         return new_store
 
-    def convertunit(self, propunit, commenttype):
+    @staticmethod
+    def convertunit(propunit, commenttype):
         """Converts a .properties unit to a .po unit. Returns None if empty or
         not for translation.
         """
@@ -233,7 +340,7 @@ class prop2po(object):
             return None
         pounit.addlocation(propunit.name)
         pounit.source = propunit.source
-        pounit.target = u""
+        pounit.target = ""
         return pounit
 
     def convertmixedunit(self, labelprop, accesskeyprop, commenttype):
@@ -253,7 +360,7 @@ class prop2po(object):
         ``mixbucket`` can be specified to indicate if the given unit is part of
         the template or the translated file.
         """
-        if self.personality != "mozilla":
+        if self.personality not in ("mozilla", "gwt"):
             # XXX should we enable unit mixing for other personalities?
             return self.convertunit(unit, commenttype)
 
@@ -272,7 +379,7 @@ class prop2po(object):
             # The mix failed before
             return self.convertunit(unit, commenttype)
 
-        #assert alreadymixed is None
+        # assert alreadymixed is None
         labelkey, accesskeykey = self.mixer.find_mixed_pair(self.mixedkeys, store, unit)
         labelprop = store.id_index.get(labelkey, None)
         accesskeyprop = store.id_index.get(accesskeykey, None)
@@ -294,30 +401,57 @@ class prop2po(object):
         return self.convertunit(unit, commenttype)
 
 
-def convertstrings(inputfile, outputfile, templatefile, personality="strings",
-                   pot=False, duplicatestyle="msgctxt", encoding=None):
+def convertstrings(
+    inputfile,
+    outputfile,
+    templatefile,
+    personality="strings",
+    pot=False,
+    duplicatestyle="msgctxt",
+    encoding=None,
+):
     """.strings specific convertor function"""
-    return convertprop(inputfile, outputfile, templatefile,
-                       personality="strings", pot=pot,
-                       duplicatestyle=duplicatestyle, encoding=encoding)
+    return convertprop(
+        inputfile,
+        outputfile,
+        templatefile,
+        personality="strings",
+        pot=pot,
+        duplicatestyle=duplicatestyle,
+        encoding=encoding,
+    )
 
 
-def convertmozillaprop(inputfile, outputfile, templatefile, pot=False,
-                       duplicatestyle="msgctxt"):
+def convertmozillaprop(
+    inputfile, outputfile, templatefile, pot=False, duplicatestyle="msgctxt"
+):
     """Mozilla specific convertor function"""
-    return convertprop(inputfile, outputfile, templatefile,
-                       personality="mozilla", pot=pot,
-                       duplicatestyle=duplicatestyle)
+    return convertprop(
+        inputfile,
+        outputfile,
+        templatefile,
+        personality="mozilla",
+        pot=pot,
+        duplicatestyle=duplicatestyle,
+    )
 
 
-def convertprop(inputfile, outputfile, templatefile, personality="java",
-                pot=False, duplicatestyle="msgctxt", encoding=None):
+def convertprop(
+    inputfile,
+    outputfile,
+    templatefile,
+    personality="java",
+    pot=False,
+    duplicatestyle="msgctxt",
+    encoding=None,
+):
     """reads in inputfile using properties, converts using prop2po, writes to
     outputfile
     """
     inputstore = properties.propfile(inputfile, personality, encoding)
-    convertor = prop2po(personality=personality, blankmsgstr=pot,
-                        duplicatestyle=duplicatestyle)
+    convertor = prop2po(
+        personality=personality, blankmsgstr=pot, duplicatestyle=duplicatestyle
+    )
     if templatefile is None:
         outputstore = convertor.convertstore(inputstore)
     else:
@@ -341,21 +475,29 @@ formats = {
 
 def main(argv=None):
     from translate.convert import convert
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         usepots=True,
-                                         description=__doc__)
+
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, usepots=True, description=__doc__
+    )
     parser.add_option(
-        "", "--personality", dest="personality",
+        "",
+        "--personality",
+        dest="personality",
         default=properties.default_dialect,
         type="choice",
         choices=list(properties.dialects.keys()),
-        help="override the input file format: %s (for .properties files, default: %s)" % (
-            ", ".join(six.iterkeys(properties.dialects)), properties.default_dialect),
-        metavar="TYPE")
+        help="override the input file format: %s (for .properties files, default: %s)"
+        % (", ".join(properties.dialects.keys()), properties.default_dialect),
+        metavar="TYPE",
+    )
     parser.add_option(
-        "", "--encoding", dest="encoding", default=None,
+        "",
+        "--encoding",
+        dest="encoding",
+        default=None,
         help="override the encoding set by the personality",
-        metavar="ENCODING")
+        metavar="ENCODING",
+    )
     parser.add_duplicates_option()
     parser.passthrough.append("pot")
     parser.passthrough.append("personality")
@@ -363,5 +505,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
