@@ -653,6 +653,13 @@ class TestHTML2POCommand(test_convert.TestConvertCommand, TestHTML2PO):
     convertmodule = html2po
     defaultoptions = {"progress": "none"}
 
+    expected_options = [
+        "-P, --pot",
+        "--duplicates=DUPLICATESTYLE",
+        "--keepcomments",
+        "--multifile=MULTIFILESTYLE",
+    ]
+
     def test_multifile_single(self):
         """Test the --multifile=single option and make sure it produces one pot file per input file."""
         self.create_testfile(
@@ -695,11 +702,3 @@ class TestHTML2POCommand(test_convert.TestConvertCommand, TestHTML2PO):
         assert "coming through" in content
         assert "cannot hear" in content
         assert err == ""
-
-    def test_help(self, capsys):
-        """Test getting help."""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
-        options = self.help_check(options, "--keepcomments")
-        options = self.help_check(options, "--multifile=MULTIFILESTYLE", last=True)
