@@ -80,10 +80,9 @@ class TestJson2POCommand(test_convert.TestConvertCommand, TestJson2PO):
     convertmodule = json2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "--duplicates")
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--filter", last=True)
+    expected_options = [
+        "-P, --pot",
+        "--duplicates",
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--filter",
+    ]
