@@ -5,7 +5,8 @@ from translate.storage import po
 
 
 class TestPO2Prop:
-    def po2prop(self, posource):
+    @staticmethod
+    def po2prop(posource):
         """helper that converts po source to .properties source without requiring files"""
         inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
@@ -13,8 +14,8 @@ class TestPO2Prop:
         outputprop = convertor.convertstore(inputpo)
         return outputprop
 
+    @staticmethod
     def merge2prop(
-        self,
         propsource,
         posource,
         personality="java",
@@ -515,14 +516,12 @@ class TestPO2PropCommand(test_convert.TestConvertCommand, TestPO2Prop):
 
     convertmodule = po2prop
     defaultoptions = {"progress": "none"}
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = super().test_help(capsys)
-        options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
-        options = self.help_check(options, "--fuzzy")
-        options = self.help_check(options, "--threshold=PERCENT")
-        options = self.help_check(options, "--personality=TYPE")
-        options = self.help_check(options, "--encoding=ENCODING")
-        options = self.help_check(options, "--removeuntranslated")
-        options = self.help_check(options, "--nofuzzy", last=True)
+    expected_options = [
+        "-t TEMPLATE, --template=TEMPLATE",
+        "--fuzzy",
+        "--threshold=PERCENT",
+        "--personality=TYPE",
+        "--encoding=ENCODING",
+        "--removeuntranslated",
+        "--nofuzzy",
+    ]
