@@ -46,7 +46,8 @@ class BaseTxt2POTester:
         """Helper that converts to target format string without using files."""
         return self._convert(*args, **kwargs)[1].getvalue().decode("utf-8")
 
-    def _count_elements(self, po_store):
+    @staticmethod
+    def _count_elements(po_store):
         """Helper that counts the number of non-header units."""
         assert po_store.units[0].isheader()
         return len(po_store.units) - 1
@@ -232,12 +233,10 @@ class TestTxt2POCommand(test_convert.TestConvertCommand, TestTxt2PO):
 
     convertmodule = txt2po
     defaultoptions = {"progress": "none"}
-
-    def test_help(self, capsys):
-        """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
-        options = self.help_check(options, "-P, --pot")
-        options = self.help_check(options, "--duplicates")
-        options = self.help_check(options, "--encoding")
-        options = self.help_check(options, "--flavour")
-        options = self.help_check(options, "--no-segmentation", last=True)
+    expected_options = [
+        "-P, --pot",
+        "--duplicates",
+        "--encoding",
+        "--flavour",
+        "--no-segmentation",
+    ]
