@@ -1,48 +1,53 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# 
-# Copyright 2007 Zuza Software Foundation
-# 
+#
+# Copyright 2007, 2016 Zuza Software Foundation
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with translate; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents Oriya language.
+"""This module represents the Odia language.
 
-For more information, see U{http://en.wikipedia.org/wiki/Oriya_language}
+.. seealso:: :wp:`Odia_language`
 """
 
+
 import re
 
 from translate.lang import common
 
+
 class code_or(common.Common):
-    """This class represents Oriya."""
+    """This class represents Odia."""
 
-    sentenceend = u"।!?…"
+    sentenceend = "।!?…"
 
-    sentencere = re.compile(r"""(?s)    #make . also match newlines
+    sentencere = re.compile(
+        r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
                             [%s]        #the puntuation for sentence ending
                             \s+         #the spacing after the puntuation
                             (?=[^a-z\d])#lookahead that next part starts with caps
-                            """ % sentenceend, re.VERBOSE)
+                            """
+        % sentenceend,
+        re.VERBOSE,
+    )
 
     puncdict = {
-        u". ": u"। ",
-        u".\n": u"।\n",
+        ". ": "। ",
+        ".\n": "।\n",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        "all": ["simplecaps", "startcaps"],
+    }
