@@ -379,7 +379,7 @@ cldr_plural_categories = [
     "other",
 ]
 
-"""List of plural tags generated from CLDR 37.0.0 using
+"""List of plural tags generated from CLDR 41.0.0 using
 https://github.com/WeblateOrg/language-data
 """
 plural_tags = {
@@ -393,6 +393,7 @@ plural_tags = {
     "asa": ["one", "other"],
     "ast": ["one", "other"],
     "az": ["one", "other"],
+    "bal": ["one", "other"],
     "be": ["one", "few", "many"],
     "bem": ["one", "other"],
     "bez": ["one", "other"],
@@ -414,6 +415,7 @@ plural_tags = {
     "cy": ["zero", "one", "two", "few", "many", "other"],
     "da": ["one", "other"],
     "de": ["one", "other"],
+    "doi": ["one", "other"],
     "dsb": ["one", "two", "few", "other"],
     "dv": ["one", "other"],
     "dz": ["other"],
@@ -421,7 +423,7 @@ plural_tags = {
     "el": ["one", "other"],
     "en": ["one", "other"],
     "eo": ["one", "other"],
-    "es": ["one", "other"],
+    "es": ["one", "many", "other"],
     "et": ["one", "other"],
     "eu": ["one", "other"],
     "fa": ["one", "other"],
@@ -429,7 +431,7 @@ plural_tags = {
     "fi": ["one", "other"],
     "fil": ["one", "other"],
     "fo": ["one", "other"],
-    "fr": ["one", "other"],
+    "fr": ["one", "many", "other"],
     "fur": ["one", "other"],
     "fy": ["one", "other"],
     "ga": ["one", "two", "few", "many", "other"],
@@ -443,6 +445,7 @@ plural_tags = {
     "haw": ["one", "other"],
     "he": ["one", "two", "many", "other"],
     "hi": ["one", "other"],
+    "hnj": ["other"],
     "hr": ["one", "few", "other"],
     "hsb": ["one", "two", "few", "other"],
     "hu": ["one", "other"],
@@ -454,7 +457,7 @@ plural_tags = {
     "in": ["other"],
     "io": ["one", "other"],
     "is": ["one", "other"],
-    "it": ["one", "other"],
+    "it": ["one", "many", "other"],
     "iu": ["one", "two", "other"],
     "iw": ["one", "two", "many", "other"],
     "ja": ["other"],
@@ -525,12 +528,11 @@ plural_tags = {
     "pl": ["one", "few", "many"],
     "prg": ["zero", "one", "other"],
     "ps": ["one", "other"],
-    "pt": ["one", "other"],
-    "pt_PT": ["one", "other"],
+    "pt": ["one", "many", "other"],
+    "pt_PT": ["one", "many", "other"],
     "rm": ["one", "other"],
     "ro": ["one", "few", "other"],
     "rof": ["one", "other"],
-    "root": ["other"],
     "ru": ["one", "few", "many"],
     "rwk": ["one", "other"],
     "sah": ["other"],
@@ -575,11 +577,13 @@ plural_tags = {
     "tl": ["one", "other"],
     "tn": ["one", "other"],
     "to": ["other"],
+    "tpi": ["other"],
     "tr": ["one", "other"],
     "ts": ["one", "other"],
     "tzm": ["one", "other"],
     "ug": ["one", "other"],
     "uk": ["one", "few", "many"],
+    "und": ["other"],
     "ur": ["one", "other"],
     "uz": ["one", "other"],
     "ve": ["one", "other"],
