@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2010 Zuza Software Foundation
 #
@@ -19,9 +18,9 @@
 
 """This module provides a factory to instantiate language classes."""
 
-from __future__ import unicode_literals
-
 import pkgutil
+from functools import lru_cache
+from importlib import import_module
 
 from translate.lang import common, data
 
@@ -29,6 +28,7 @@ from translate.lang import common, data
 prefix = "code_"
 
 
+@lru_cache(maxsize=128)
 def getlanguage(code):
     """This returns a language class.
 
@@ -39,15 +39,14 @@ def getlanguage(code):
     try:
         if code is None:
             raise ImportError("Can't determine language code")
-        if code in ('or', 'is', 'as'):
+        if code in ("or", "is", "as"):
             internal_code = prefix + code
         else:
             internal_code = code
-        module = __import__("translate.lang.%s" % internal_code, globals(), {},
-                            internal_code)
+        module = import_module("translate.lang.%s" % internal_code)
         langclass = getattr(module, internal_code)
         return langclass(code)
-    except ImportError as e:
+    except ImportError:
         simplercode = data.simplercode(code)
         if simplercode:
             relatedlanguage = getlanguage(simplercode)
@@ -62,10 +61,10 @@ def get_all_languages():
     """Return all language classes."""
     import translate.lang as package
 
-    is_language_module = lambda x: not (x.startswith("test_")
-                                        or x in ("common", "data", "factory",
-                                                 "identify", "ngram", "poedit",
-                                                 "team"))
+    is_language_module = lambda x: not (
+        x.startswith("test_")
+        or x in ("common", "data", "factory", "identify", "ngram", "poedit", "team")
+    )
     lang_codes = []
     for _imp, modname, _isp in pkgutil.walk_packages(package.__path__):
         if is_language_module(modname):
