@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -20,14 +19,13 @@
 """This module represents the Finnish language.
 """
 
+
 from translate.lang import common
 
 
 class fi(common.Common):
     """This class represents Finnish."""
 
-    validaccel = (u"abcdefghijklmnopqrstuvwxyz"
-                  u"ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                  u"1234567890"
-                  u"äö"
-                  u"ÄÖ")
+    validaccel = (
+        "abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "1234567890" "äö" "ÄÖ"
+    )
