@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -30,10 +28,10 @@ from translate.misc.file_discovery import get_abs_data_filename
 from translate.storage.base import TranslationStore
 
 
-class LanguageIdentifier(object):
-    MODEL_DIR = get_abs_data_filename('langmodels')
+class LanguageIdentifier:
+    MODEL_DIR = get_abs_data_filename("langmodels")
     """The directory containing the ngram language model files."""
-    CONF_FILE = 'fpdb.conf'
+    CONF_FILE = "fpdb.conf"
     """
     The name of the file that contains language name-code pairs
     (relative to ``MODEL_DIR``).
@@ -43,13 +41,13 @@ class LanguageIdentifier(object):
         if model_dir is None:
             model_dir = self.MODEL_DIR
         if not path.isdir(model_dir):
-            raise ValueError('Directory does not exist: %s' % (model_dir))
+            raise ValueError("Directory does not exist: %s" % (model_dir))
 
         if conf_file is None:
             conf_file = self.CONF_FILE
         conf_file = path.abspath(path.join(model_dir, conf_file))
         if not path.isfile(conf_file):
-            raise ValueError('File does not exist: %s' % (conf_file))
+            raise ValueError("File does not exist: %s" % (conf_file))
 
         self._lang_codes = {}
         self._load_config(conf_file)
@@ -57,26 +55,27 @@ class LanguageIdentifier(object):
 
     def _load_config(self, conf_file):
         """Load the mapping of language names to language codes as given in the
-            configuration file."""
-        lines = open(conf_file).read().splitlines()
-        for line in lines:
-            parts = line.split()
-            if not parts or line.startswith('#'):
-                continue  # Skip comment- and empty lines
-            lname, lcode = parts[0], parts[1]
+        configuration file.
+        """
+        with open(conf_file) as fp:
+            for line in fp:
+                parts = line.split()
+                if not parts or line.startswith("#"):
+                    continue  # Skip comment- and empty lines
+                lname, lcode = parts[0], parts[1]
 
-            # Make sure lname is not prefixed by directory names
-            lname = path.split(lname)[-1]
-            if extsep in lname:
-                lname = lname[:lname.rindex(extsep)]  # Remove extension if it has
+                # Make sure lname is not prefixed by directory names
+                lname = path.split(lname)[-1]
+                if extsep in lname:
+                    lname = lname[: lname.rindex(extsep)]  # Remove extension if it has
 
-            # Remove trailing '[_-]-utf8' from code
-            if lcode.endswith('-utf8'):
-                lcode = lcode[:-len('-utf8')]
-            if lcode.endswith('-') or lcode.endswith('_'):
-                lcode = lcode[:-1]
+                # Remove trailing '[_-]-utf8' from code
+                if lcode.endswith("-utf8"):
+                    lcode = lcode[: -len("-utf8")]
+                if lcode.endswith("-") or lcode.endswith("_"):
+                    lcode = lcode[:-1]
 
-            self._lang_codes[lname] = lcode
+                self._lang_codes[lname] = lcode
 
     def identify_lang(self, text):
         """Identify the language of the text in the given string."""
@@ -89,43 +88,54 @@ class LanguageIdentifier(object):
 
     def identify_source_lang(self, instore):
         """Identify the source language of the given translation store or
-            units.
+        units.
 
-            :type  instore: ``TranslationStore`` or list or tuple of
-                ``TranslationUnit``s.
-            :param instore: The translation store to extract source text from.
-            :returns: The identified language's code or ``None`` if the language
-                could not be identified."""
+        :type  instore: ``TranslationStore`` or list or tuple of
+            ``TranslationUnit``s.
+        :param instore: The translation store to extract source text from.
+        :returns: The identified language's code or ``None`` if the language
+            could not be identified.
+        """
         if not isinstance(instore, (TranslationStore, list, tuple)):
             return None
 
-        text = u' '.join(unit.source for unit in instore[:50] if unit.istranslatable() and unit.source)
+        text = " ".join(
+            unit.source
+            for unit in instore[:50]
+            if unit.istranslatable() and unit.source
+        )
         if not text:
             return None
         return self.identify_lang(text)
 
     def identify_target_lang(self, instore):
         """Identify the target language of the given translation store or
-            units.
+        units.
 
-            :type  instore: ``TranslationStore`` or list or tuple of
-                ``TranslationUnit``s.
-            :param instore: The translation store to extract target text from.
-            :returns: The identified language's code or ``None`` if the language
-                could not be identified."""
+        :type  instore: ``TranslationStore`` or list or tuple of
+            ``TranslationUnit``s.
+        :param instore: The translation store to extract target text from.
+        :returns: The identified language's code or ``None`` if the language
+            could not be identified.
+        """
         if not isinstance(instore, (TranslationStore, list, tuple)):
             return None
 
-        text = u' '.join(unit.target for unit in instore[:200] if unit.istranslatable() and unit.target)
+        text = " ".join(
+            unit.target
+            for unit in instore[:200]
+            if unit.istranslatable() and unit.target
+        )
         if not text:
             return None
         return self.identify_lang(text)
 
+
 if __name__ == "__main__":
     from sys import argv
+
     script_dir = path.abspath(path.dirname(argv[0]))
     identifier = LanguageIdentifier()
-    import locale
-    encoding = locale.getpreferredencoding()
-    text = file(argv[1]).read().decode(encoding)
+    with open(argv[1]) as fh:
+        text = fh.read()
     print("Language detected:", identifier.identify_lang(text))
