@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008, 2016 Zuza Software Foundation
 #
@@ -19,10 +18,9 @@
 
 """This module represents the Malayalam language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Malayalam_language
+.. seealso:: :wp:`Malayalam_language`
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
@@ -31,5 +29,5 @@ class ml(common.Common):
     """This class represents Malayalam."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
