@@ -1,7 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
-# Copyright 2013 Zuza Software Foundation
+# Copyright 2013, 2016 Zuza Software Foundation
 #
 # This file is part of the Translate Toolkit.
 #
@@ -20,9 +18,10 @@
 
 """This module represents the Burmese language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Burmese_language
+.. seealso:: :wp:`Burmese_language`
 """
 
+
 from translate.lang import common
 
 
@@ -30,7 +29,9 @@ class my(common.Common):
     """This class represents Burmese."""
 
     puncdict = {
-        u".": u"။",
+        ".": "။",
     }
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        "all": ["simplecaps", "startcaps"],
+    }
