@@ -9,7 +9,9 @@ def test_isocode():
     assert isocode("Portuguese") == "pt"  # No country we default to 'None'
     assert isocode("Portuguese", "BRAZIL") == "pt_BR"  # Country with a valid dialect
     assert isocode("Portuguese", "PORTUGAL") == "pt"
-    assert isocode("Portuguese", "MOZAMBIQUE") == "pt"  # Country is not a dialect so use default
+    assert (
+        isocode("Portuguese", "MOZAMBIQUE") == "pt"
+    )  # Country is not a dialect so use default
     # Dialect lookups: English
     assert isocode("English") == "en"
     assert isocode("English", "UNITED KINGDOM") == "en_GB"
