@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -19,23 +18,24 @@
 
 """This module represents the Uyghur language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Uyghur_language
+.. seealso:: :wp:`Uyghur_language`
 """
 
+
 from translate.lang import common
 
 
 class ug(common.Common):
     """This class represents Uyghur."""
 
-    listseperator = u"، "
+    listseperator = "، "
 
     puncdict = {
-        u",": u"،",
-        u";": u"؛",
-        u"?": u"؟",
+        ",": "،",
+        ";": "؛",
+        "?": "؟",
     }
 
     ignoretests = {
-        'all': ["acronyms", "simplecaps", "startcaps"],
+        "all": ["acronyms", "simplecaps", "startcaps"],
     }
