@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -19,10 +18,9 @@
 
 """This module represents the Chinese language (simplified).
 
-.. seealso:: http://en.wikipedia.org/wiki/Chinese_language
+.. seealso:: :wp:`Chinese_language`
 """
 
-from __future__ import unicode_literals
 
 from translate.lang.zh import zh
 
@@ -31,5 +29,5 @@ class zh_cn(zh):
     specialchars = "←→↔×÷©…—‘’“”【】《》"
 
     ignoretests = {
-        'all': ["acronyms", "simplecaps", "startcaps"],
+        "all": ["acronyms", "simplecaps", "startcaps"],
     }
