@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
 #
@@ -21,10 +20,9 @@
 delimiters
 """
 
+import html.entities
 import logging
-import six
-
-from six.moves import html_entities
+import re
 
 
 def find_all(searchin, substr):
@@ -42,8 +40,9 @@ def find_all(searchin, substr):
     return locations
 
 
-def extract(source, startdelim, enddelim,
-            escape=None, startinstring=False, allowreentry=True):
+def extract(
+    source, startdelim, enddelim, escape=None, startinstring=False, allowreentry=True
+):
     """Extracts a doublequote-delimited string from a string, allowing for
     backslash-escaping returns tuple of (quoted string with quotes, still in
     string at end).
@@ -71,12 +70,20 @@ def extract(source, startdelim, enddelim,
                 true_escape = True
             if true_escape:
                 true_escape_places.append(escape_pos)
-        startdelim_places = [pos for pos in startdelim_places if pos - lenescape not in true_escape_places]
-        enddelim_places = [pos + lenend for pos in enddelim_places if pos - lenescape not in true_escape_places]
+        startdelim_places = [
+            pos
+            for pos in startdelim_places
+            if pos - lenescape not in true_escape_places
+        ]
+        enddelim_places = [
+            pos + lenend
+            for pos in enddelim_places
+            if pos - lenescape not in true_escape_places
+        ]
     else:
         enddelim_places = [pos + lenend for pos in enddelim_places]
     # Get a unique sorted list of the significant places in the string
-    significant_places = [0] + startdelim_places + enddelim_places + [len(source)-1]
+    significant_places = [0] + startdelim_places + enddelim_places + [len(source) - 1]
     significant_places.sort()
     extracted = ""
     lastpos = None
@@ -89,8 +96,11 @@ def extract(source, startdelim, enddelim,
             extracted += source[lastpos:pos]
             instring = False
             lastpos = pos
-        if ((not instring) and pos in startdelim_places and
-            not (enteredonce and not allowreentry)):
+        if (
+            (not instring)
+            and pos in startdelim_places
+            and not (enteredonce and not allowreentry)
+        ):
             instring = True
             enteredonce = True
             lastpos = pos
@@ -99,9 +109,15 @@ def extract(source, startdelim, enddelim,
     return (extracted, instring)
 
 
-def extractwithoutquotes(source, startdelim, enddelim, escape=None,
-                         startinstring=False, includeescapes=True,
-                         allowreentry=True):
+def extractwithoutquotes(
+    source,
+    startdelim,
+    enddelim,
+    escape=None,
+    startinstring=False,
+    includeescapes=True,
+    allowreentry=True,
+):
     """Extracts a doublequote-delimited string from a string, allowing for
     backslash-escaping includeescapes can also be a function that takes the
     whole escaped string and returns the replaced version.
@@ -115,7 +131,7 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
         enddelim_places = startdelim_places[:]
     else:
         enddelim_places = find_all(source, enddelim)
-    #hell slow because it is called far too often
+    # hell slow because it is called far too often
     if escape is not None:
         lenescape = len(escape)
         escape_places = find_all(source, escape)
@@ -129,12 +145,20 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
                 true_escape = True
             if true_escape:
                 true_escape_places.append(escape_pos)
-        startdelim_places = [pos for pos in startdelim_places if pos - lenescape not in true_escape_places]
-        enddelim_places = [pos + lenend for pos in enddelim_places if pos - lenescape not in true_escape_places]
+        startdelim_places = [
+            pos
+            for pos in startdelim_places
+            if pos - lenescape not in true_escape_places
+        ]
+        enddelim_places = [
+            pos + lenend
+            for pos in enddelim_places
+            if pos - lenescape not in true_escape_places
+        ]
     else:
         enddelim_places = [pos + lenend for pos in enddelim_places]
     # get a unique sorted list of the significant places in the string
-    significant_places = [0] + startdelim_places + enddelim_places + [len(source)-1]
+    significant_places = [0] + startdelim_places + enddelim_places + [len(source) - 1]
     significant_places.sort()
     extracted = ""
     lastpos = 0
@@ -145,20 +169,28 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
             section_start, section_end = lastpos + len(startdelim), pos - len(enddelim)
             section = source[section_start:section_end]
             if escape is not None and checkescapes:
-                escape_list = [epos - section_start for epos in true_escape_places if section_start <= epos <= section_end]
+                escape_list = [
+                    epos - section_start
+                    for epos in true_escape_places
+                    if section_start <= epos <= section_end
+                ]
                 new_section = ""
                 last_epos = 0
                 for epos in escape_list:
                     new_section += section[last_epos:epos]
                     if callable_includeescapes:
-                        replace_escape = includeescapes(section[epos:epos + lenescape + 1])
+                        replace_escape = includeescapes(
+                            section[epos : epos + lenescape + 1]
+                        )
                         # TODO: deprecate old method of returning boolean from
                         # includeescape, by removing this if block
-                        if not isinstance(replace_escape, six.string_types):
+                        if not isinstance(replace_escape, str):
                             if replace_escape:
-                                replace_escape = section[epos:epos + lenescape + 1]
+                                replace_escape = section[epos : epos + lenescape + 1]
                             else:
-                                replace_escape = section[epos + lenescape:epos + lenescape + 1]
+                                replace_escape = section[
+                                    epos + lenescape : epos + lenescape + 1
+                                ]
                         new_section += replace_escape
                         last_epos = epos + lenescape + 1
                     else:
@@ -167,8 +199,11 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
             extracted += section
             instring = False
             lastpos = pos
-        if ((not instring) and pos in startdelim_places and
-            not (enteredonce and not allowreentry)):
+        if (
+            (not instring)
+            and pos in startdelim_places
+            and not (enteredonce and not allowreentry)
+        ):
             instring = True
             enteredonce = True
             lastpos = pos
@@ -176,13 +211,18 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
         section_start = lastpos + len(startdelim)
         section = source[section_start:]
         if escape is not None and not includeescapes:
-            escape_list = [epos - section_start for epos in true_escape_places if section_start <= epos]
+            escape_list = [
+                epos - section_start
+                for epos in true_escape_places
+                if section_start <= epos
+            ]
             new_section = ""
             last_epos = 0
             for epos in escape_list:
                 new_section += section[last_epos:epos]
-                if (callable_includeescapes and
-                    includeescapes(section[epos:epos + lenescape + 1])):
+                if callable_includeescapes and includeescapes(
+                    section[epos : epos + lenescape + 1]
+                ):
                     last_epos = epos
                 else:
                     last_epos = epos + lenescape
@@ -194,7 +234,7 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
 def _encode_entity_char(char, codepoint2name):
     charnum = ord(char)
     if charnum in codepoint2name:
-        return u"&%s;" % codepoint2name[charnum]
+        return "&%s;" % codepoint2name[charnum]
     else:
         return char
 
@@ -207,7 +247,7 @@ def entityencode(source, codepoint2name):
            (without the the leading ``&`` or the trailing ``;``)
     :type codepoint2name: :meth:`dict`
     """
-    output = u""
+    output = ""
     inentity = False
     for char in source:
         if char == "&":
@@ -219,8 +259,9 @@ def entityencode(source, codepoint2name):
                 output += "&" + possibleentity + ";"
                 inentity = False
             elif char == " ":
-                output += (_encode_entity_char("&", codepoint2name) +
-                           entityencode(possibleentity + char, codepoint2name))
+                output += _encode_entity_char("&", codepoint2name) + entityencode(
+                    possibleentity + char, codepoint2name
+                )
                 inentity = False
             else:
                 possibleentity += char
@@ -228,8 +269,9 @@ def entityencode(source, codepoint2name):
             output += _encode_entity_char(char, codepoint2name)
     if inentity:
         # Handle nonentities at end of string.
-        output += (_encode_entity_char("&", codepoint2name) +
-                   entityencode(possibleentity, codepoint2name))
+        output += _encode_entity_char("&", codepoint2name) + entityencode(
+            possibleentity, codepoint2name
+        )
 
     return output
 
@@ -251,7 +293,7 @@ def entitydecode(source, name2codepoint):
            the leading ``&`` or the trailing ``;``) to code points
     :type name2codepoint: :meth:`dict`
     """
-    output = u""
+    output = ""
     inentity = False
     for i, char in enumerate(source):
         char = source[i]
@@ -261,10 +303,9 @@ def entitydecode(source, name2codepoint):
             continue
         if inentity:
             if char == ";":
-                if (len(possibleentity) > 0 and
-                    possibleentity in name2codepoint):
-                    entchar = six.unichr(name2codepoint[possibleentity])
-                    if entchar == u'&' and _has_entity_end(source[i+1:]):
+                if len(possibleentity) > 0 and possibleentity in name2codepoint:
+                    entchar = chr(name2codepoint[possibleentity])
+                    if entchar == "&" and _has_entity_end(source[i + 1 :]):
                         output += "&" + possibleentity + ";"
                     else:
                         output += entchar
@@ -286,28 +327,28 @@ def entitydecode(source, name2codepoint):
 
 
 def htmlentityencode(source):
-    u"""Encode ``source`` using HTML entities e.g. © -> ``&copy;``
+    """Encode ``source`` using HTML entities e.g. © -> ``&copy;``
 
     :param unicode source: Source string to encode
     """
-    return entityencode(source, html_entities.codepoint2name)
+    return entityencode(source, html.entities.codepoint2name)
 
 
 def htmlentitydecode(source):
-    u"""Decode source using HTML entities e.g. ``&copy;`` -> ©.
+    """Decode source using HTML entities e.g. ``&copy;`` -> ©.
 
     :param unicode source: Source string to decode
     """
-    return entitydecode(source, html_entities.name2codepoint)
+    return entitydecode(source, html.entities.name2codepoint)
 
 
 def javapropertiesencode(source):
     """Encodes source in the escaped-unicode encoding used by Java
     .properties files
     """
-    output = u""
-    if source and source[0] == u" ":
-        output = u"\\"
+    output = ""
+    if source and source[0] == " ":
+        output = "\\"
     for char in source:
         charnum = ord(char)
         if char in controlchars:
@@ -315,7 +356,7 @@ def javapropertiesencode(source):
         elif 0 <= charnum < 128:
             output += str(char)
         else:
-            output += u"\\u%04X" % charnum
+            output += "\\u%04X" % charnum
     return output
 
 
@@ -323,7 +364,7 @@ def java_utf8_properties_encode(source):
     """Encodes source in the escaped-unicode encoding used by java utf-8
     .properties files.
     """
-    output = u""
+    output = ""
     for char in source:
         if char in controlchars:
             output += controlchars[char]
@@ -332,23 +373,32 @@ def java_utf8_properties_encode(source):
     return output
 
 
+def xwiki_properties_encode(source, encoding):
+    if re.search(r"\{[0-9]+\}", source):
+        source = source.replace("'", "''")
+    if encoding == "utf-8":
+        return java_utf8_properties_encode(source)
+    else:
+        return javapropertiesencode(source)
+
+
 def escapespace(char):
-    assert(len(char) == 1)
+    assert len(char) == 1
     if char.isspace():
-        return u"\\u%04X" % ord(char)
+        return "\\u%04X" % ord(char)
     return char
 
 
 def mozillaescapemarginspaces(source):
     """Escape leading and trailing spaces for Mozilla .properties files."""
     if not source:
-        return u""
+        return ""
 
     if len(source) == 1 and source.isspace():
         # FIXME: This is hack for people using white-space to mark empty
         # Mozilla strings translated, drop this once we have better way to
         # handle this in Pootle.
-        return u""
+        return ""
 
     if len(source) == 1:
         return escapespace(source)
@@ -358,21 +408,29 @@ def mozillaescapemarginspaces(source):
 
 propertyescapes = {
     # escapes that are self-escaping
-    "\\": "\\", "'": "'", '"': '"',
+    "\\": "\\",
+    "'": "'",
+    '"': '"',
     # control characters that we keep
-    "f": "\f", "n": "\n", "r": "\r", "t": "\t",
+    "f": "\f",
+    "n": "\n",
+    "r": "\r",
+    "t": "\t",
 }
 
 controlchars = {
     # the reverse of the above...
     "\\": "\\\\",
-    "\f": "\\f", "\n": "\\n", "\r": "\\r", "\t": "\\t",
+    "\f": "\\f",
+    "\n": "\\n",
+    "\r": "\\r",
+    "\t": "\\t",
 }
 
 
 def escapecontrols(source):
     """escape control characters in the given string"""
-    for key, value in six.iteritems(controlchars):
+    for key, value in controlchars.items():
         source = source.replace(key, value)
     return source
 
@@ -387,7 +445,7 @@ def propertiesdecode(source):
     don't want to we reimplemented the algorithm from Python Objects/unicode.c
     in Python and modify it to retain escaped control characters.
     """
-    output = u""
+    output = ""
     s = 0
 
     def unichr2(i):
@@ -395,16 +453,16 @@ def propertiesdecode(source):
         otherwise an escaped control character.
         """
         if 32 <= i:
-            return six.unichr(i)
-        elif six.unichr(i) in controlchars:
+            return chr(i)
+        elif chr(i) in controlchars:
             # we just return the character, unescaped
             # if people want to escape them they can use escapecontrols
-            return six.unichr(i)
+            return chr(i)
         return "\\u%04x" % i
 
     while s < len(source):
         c = source[s]
-        if c != '\\':
+        if c != "\\":
             output += c
             s += 1
             continue
@@ -416,7 +474,7 @@ def propertiesdecode(source):
             continue
         c = source[s]
         s += 1
-        if c == '\n':
+        if c == "\n":
             pass
         # propertyescapes lookups
         elif c in propertyescapes:
@@ -434,9 +492,9 @@ def propertiesdecode(source):
                 if c.isdigit() or c in "abcdef":
                     x <<= 4
                     if c.isdigit():
-                        x += ord(c) - ord('0')
+                        x += ord(c) - ord("0")
                     else:
-                        x += ord(c) - ord('a') + 10
+                        x += ord(c) - ord("a") + 10
                 else:
                     digits = digit
                     break
@@ -444,16 +502,17 @@ def propertiesdecode(source):
             output += unichr2(x)
         elif c == "N":
             if source[s] != "{":
-                logging.warn("Invalid named unicode escape: no { after \\N")
+                logging.warning("Invalid named unicode escape: no { after \\N")
                 output += "\\" + c
                 continue
             s += 1
             e = source.find("}", s)
             if e == -1:
-                logging.warn("Invalid named unicode escape: no } after \\N{")
+                logging.warning("Invalid named unicode escape: no } after \\N{")
                 output += "\\" + c
                 continue
             import unicodedata
+
             name = source[s:e]
             output += unicodedata.lookup(name)
             s = e + 1
@@ -462,6 +521,12 @@ def propertiesdecode(source):
     return output
 
 
+def xwiki_properties_decode(source):
+    if re.search(r"\{[0-9]+\}", source):
+        source = source.replace("''", "'")
+    return propertiesdecode(source)
+
+
 def findend(string, substring):
     s = string.find(substring)
     if s != -1:
