@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-
 from pytest import deprecated_call, mark
 
 from translate.misc.deprecation import deprecated
 
 
-class TestDeprecation(object):
+class TestDeprecation:
 
     # Deprecated on 2.x.x
     @deprecated("Use XXX instead")
