@@ -543,7 +543,7 @@ class pounit(pocommon.pounit):
         #            id = '%s\0%s' % (id, plural)
         context = gpo.po_message_msgctxt(self._gpo_message)
         if context:
-            id = "{}\04{}".format(gpo_decode(context), id)
+            id = f"{gpo_decode(context)}\04{id}"
         return id
 
     def getnotes(self, origin=None):
@@ -559,7 +559,7 @@ class pounit(pocommon.pounit):
             raise ValueError("Comment type not valid")
 
         if comments and get_libgettextpo_version() < (0, 17, 0):
-            comments = "\n".join([line for line in comments.split("\n")])
+            comments = "\n".join(line for line in comments.split("\n"))
         # Let's drop the last newline
         return gpo_decode(comments[:-1])
 
@@ -584,7 +584,7 @@ class pounit(pocommon.pounit):
             else:
                 newnotes = text + "\n" + oldnotes
         else:
-            newnotes = "\n".join([line.rstrip("\r") for line in text.split("\n")])
+            newnotes = "\n".join(line.rstrip("\r") for line in text.split("\n"))
 
         if newnotes:
             newlines = []
@@ -757,7 +757,7 @@ class pounit(pocommon.pounit):
         """Build a native unit from a foreign unit, preserving as much
         information as possible.
         """
-        if type(unit) == cls and hasattr(unit, "copy") and callable(unit.copy):
+        if type(unit) is cls and hasattr(unit, "copy") and callable(unit.copy):
             return unit.copy()
         elif isinstance(unit, pocommon.pounit):
             newunit = cls(unit.source, encoding)
@@ -819,7 +819,7 @@ class pofile(pocommon.pofile):
     def _insert_header(self, header):
         header._store = self
         self.units.insert(0, header)
-        gpo.po_message_iterator_free(self._gpo_message_iterator)
+        self._free_iterator()
         self._gpo_message_iterator = gpo.po_message_iterator(
             self._gpo_memory_file, None
         )
@@ -881,8 +881,9 @@ class pofile(pocommon.pofile):
         new_gpo_message_iterator = gpo.po_message_iterator(new_gpo_memory_file, None)
         for unit in uniqueunits:
             gpo.po_message_insert(new_gpo_message_iterator, unit._gpo_message)
-        gpo.po_message_iterator_free(self._gpo_message_iterator)
+        self._free_iterator()
         self._gpo_message_iterator = new_gpo_message_iterator
+        self._free_memory_file()
         self._gpo_memory_file = new_gpo_memory_file
         self.units = uniqueunits
 
@@ -901,11 +902,13 @@ class pofile(pocommon.pofile):
 
         def writefile(filename):
             xerror_storage.exception = None
-            self._gpo_memory_file = gpo.po_file_write_v2(
+            result = gpo.po_file_write_v2(
                 self._gpo_memory_file, gpo_encode(filename), xerror_handler
             )
             if xerror_storage.exception is not None:
                 raise xerror_storage.exception
+            if result is None:
+                raise ValueError("Unknown error while saving file")
             with open(filename, "rb") as tfile:
                 return tfile.read()
 
@@ -914,20 +917,22 @@ class pofile(pocommon.pofile):
             obsolete_workaround()
             f, fname = tempfile.mkstemp(prefix="translate", suffix=".po")
             os.close(f)
-            outputstring = writefile(fname)
-            if self.encoding != pounit.CPO_ENC:
-                try:
-                    outputstring = outputstring.decode(pounit.CPO_ENC).encode(
-                        self.encoding
-                    )
-                except UnicodeEncodeError:
-                    self.encoding = pounit.CPO_ENC
-                    self.updateheader(
-                        content_type="text/plain; charset=UTF-8",
-                        content_transfer_encoding="8bit",
-                    )
-                    outputstring = writefile(fname)
-            os.remove(fname)
+            try:
+                outputstring = writefile(fname)
+                if self.encoding != pounit.CPO_ENC:
+                    try:
+                        outputstring = outputstring.decode(pounit.CPO_ENC).encode(
+                            self.encoding
+                        )
+                    except UnicodeEncodeError:
+                        self.encoding = pounit.CPO_ENC
+                        self.updateheader(
+                            content_type="text/plain; charset=UTF-8",
+                            content_transfer_encoding="8bit",
+                        )
+                        outputstring = writefile(fname)
+            finally:
+                os.remove(fname)
         out.write(outputstring)
 
     def isempty(self):
@@ -964,15 +969,19 @@ class pofile(pocommon.pofile):
             input = fname
             os.close(fd)
 
-        xerror_storage.exception = None
-        self._gpo_memory_file = gpo.po_file_read_v3(gpo_encode(input), xerror_handler)
-        if xerror_storage.exception is not None:
-            raise xerror_storage.exception
-        if self._gpo_memory_file is None:
-            logger.error("Error:")
-
-        if needtmpfile:
-            os.remove(input)
+        try:
+            xerror_storage.exception = None
+            self._free_memory_file()
+            self._gpo_memory_file = gpo.po_file_read_v3(
+                gpo_encode(input), xerror_handler
+            )
+            if xerror_storage.exception is not None:
+                raise xerror_storage.exception
+            if self._gpo_memory_file is None:
+                logger.error("Error:")
+        finally:
+            if needtmpfile:
+                os.remove(input)
 
         self.units = []
         # Handle xerrors here
@@ -984,6 +993,7 @@ class pofile(pocommon.pofile):
             if charset:
                 charset = re.search("charset=([^\\s]+)", charset).group(1)
             self.encoding = charset
+        self._free_iterator()
         self._gpo_message_iterator = gpo.po_message_iterator(
             self._gpo_memory_file, None
         )
@@ -995,18 +1005,16 @@ class pofile(pocommon.pofile):
         self._free_iterator()
 
     def __del__(self):
-        # We currently disable this while we still get segmentation faults.
-        # Note that this is definitely leaking memory because of this.
-        return
         self._free_iterator()
+        self._free_memory_file()
+
+    def _free_memory_file(self):
+        return
         if self._gpo_memory_file is not None:
             gpo.po_file_free(self._gpo_memory_file)
             self._gpo_memory_file = None
 
     def _free_iterator(self):
-        # We currently disable this while we still get segmentation faults.
-        # Note that this is definitely leaking memory because of this.
-        return
         if self._gpo_message_iterator is not None:
             gpo.po_message_iterator_free(self._gpo_message_iterator)
             self._gpo_message_iterator = None
