@@ -126,7 +126,6 @@ Name and Value pairs:
 
 """
 
-import collections
 import re
 from codecs import iterencode
 from copy import deepcopy
@@ -438,7 +437,7 @@ class DialectGaia(DialectMozilla):
 
 @register_dialect
 class DialectGwt(DialectJavaUtf8):
-    plural_regex = re.compile(r"([^\[\]]*)(?:\[(.*)\])?")
+    plural_regex = re.compile(r"(.*?)(?:\[(.+)\])?")
     name = "gwt"
     delimiters = ["="]
     has_plurals = True
@@ -484,7 +483,10 @@ class DialectGwt(DialectJavaUtf8):
 
     @classmethod
     def encode(cls, string, encoding=None):
-        result = super().encode(string, encoding)
+        if encoding not in ("utf-8", "utf-16"):
+            result = quote.javapropertiesencode(string or "")
+        else:
+            result = quote.java_utf8_properties_encode(string or "")
         return result.replace("'", "''")
 
     @classmethod
@@ -538,7 +540,7 @@ class DialectStrings(Dialect):
 
     @staticmethod
     def encode(string, encoding=None):
-        return string.replace("\n", r"\n").replace("\t", r"\t")
+        return string.replace("\\", "\\\\").replace("\n", r"\n").replace("\t", r"\t")
 
     @staticmethod
     def is_line_continuation(line):
@@ -565,7 +567,7 @@ class proppluralunit(base.TranslationUnit):
         """Construct a blank propunit."""
         self.personality = get_dialect(personality)
         super().__init__(source)
-        self.units = collections.OrderedDict()
+        self.units = {}
         self.name = ""
 
     @staticmethod
@@ -1097,9 +1099,7 @@ class propfile(base.TranslationStore):
                 self.addunit(unit)
                 continue
             (key, variant) = self.personality.get_key_cldr_name(unit.name)
-            print(f"fold: {key!r} {variant!r} < {unit.name!r}")
             if key not in plurals or plurals[key].hasplural(variant):
-                print(f"generate {key!r}")
                 # Generate fake unit for each keys (MUST use None as source)
                 new_unit = proppluralunit(None, self.personality.name)
                 new_unit.name = key
