@@ -142,7 +142,6 @@ class PoWrapper(textwrap.TextWrapper):
             \s+|                                  # any whitespace
             [a-z0-9A-Z_-]+/|                      # nicely split long URLs
             \w*\\.\w*|                            # any escape should not be split
-            n(?=%)|                               # wrap insidide plural equation
             \.(?=\w)|                             # full stop inside word
             [\w\!\'\&\.\,\?=<>%]+\s+|             # space should go with a word
             [^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|  # hyphenated words
@@ -559,10 +558,7 @@ class pounit(pocommon.pounit):
 
     def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
-            combinedstr = self.newline.join(
-                filter(None, [unquotefrompo(msgstr) for msgstr in self.msgstr.values()])
-            )
-            return len(combinedstr)
+            return sum(len(unquotefrompo(msgstr)) for msgstr in self.msgstr.values())
         return len(unquotefrompo(self.msgstr))
 
     def merge(self, otherpo, overwrite=False, comments=True, authoritative=False):
