@@ -1,20 +1,17 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function
-
 import sys
+from io import BytesIO
 
 from pytest import importorskip, mark, raises
 
-pytestmark = mark.skipif(
-    not sys.platform.startswith('linux'),
-    reason="cpo is only available on Linux"
-)
-
-from translate.misc import wStringIO
 from translate.misc.multistring import multistring
 from translate.storage import test_po
 
 
+pytestmark = mark.skipif(
+    not sys.platform.startswith("linux"), reason="cpo is only available on Linux"
+)
+
+
 cpo = importorskip("translate.storage.cpo")
 
 
@@ -39,11 +36,11 @@ class TestCPOUnit(test_po.TestPOUnit):
         assert unit.target.strings == ["Koei", "Koeie"]
         assert unit.target == "Koei"
 
-        unit.target = [u"Sk\u00ear", u"Sk\u00eare"]
+        unit.target = ["Sk\u00ear", "Sk\u00eare"]
         assert isinstance(unit.target, multistring)
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target.strings == [u"Sk\u00ear", u"Sk\u00eare"]
-        assert unit.target == u"Sk\u00ear"
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target.strings == ["Sk\u00ear", "Sk\u00eare"]
+        assert unit.target == "Sk\u00ear"
 
     def test_plural_reduction(self):
         """checks that reducing the number of plurals supplied works"""
@@ -75,14 +72,15 @@ class TestCPOUnit(test_po.TestPOUnit):
         unit.addnote("Thank you", origin="translator")
         assert unit.getnotes("translator") == "Which meaning of file?\nThank you"
         assert unit.getnotes() == "Which meaning of file?\nThank you\nVerb"
-        assert raises(ValueError, unit.getnotes, "devteam")
+        with raises(ValueError):
+            unit.getnotes("devteam")
 
     def test_notes_withcomments(self):
         """tests that when we add notes that look like comments that we treat them properly"""
         unit = self.UnitClass("File")
         unit.addnote("# Double commented comment")
         assert unit.getnotes() == "# Double commented comment"
-        assert not unit.hastypecomment('c-format')
+        assert not unit.hastypecomment("c-format")
 
 
 class TestCPOFile(test_po.TestPOFile):
@@ -115,15 +113,17 @@ class TestCPOFile(test_po.TestPOFile):
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
     def test_merge_blanks(self):
         """checks that merging adds msgid_comments to blanks"""
-        posource = '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
+        posource = (
+            '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
+        )
         pofile = self.poparse(posource)
         assert len(pofile.units) == 2
         pofile.removeduplicates("merge")
         assert len(pofile.units) == 2
         print(pofile.units[0].msgidcomments)
         print(pofile.units[1].msgidcomments)
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == "_: source1\n"
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == "_: source1\n"
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source2\n"
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
     def test_msgid_comment(self):
@@ -133,43 +133,49 @@ class TestCPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 2
         pofile.removeduplicates("msgid_comment")
         assert len(pofile.units) == 2
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == "_: source0\n"
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == "_: source1\n"
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == "_: source0\n"
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == "_: source1\n"
         # Now lets check for formating
         for i in (0, 1):
-            expected = '''#: source%d\nmsgid ""\n"_: source%d\\n"\n"Same"\nmsgstr ""\n''' % (i, i)
+            expected = (
+                """#: source%d\nmsgid ""\n"_: source%d\\n"\n"Same"\nmsgstr ""\n"""
+                % (i, i)
+            )
             assert pofile.units[i].__str__() == expected
 
     @mark.xfail(reason="Were disabled during port of Pypo to cPO - they might work")
     def test_keep_blanks(self):
         """checks that keeping keeps blanks and doesn't add msgid_comments"""
-        posource = '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
+        posource = (
+            '#: source1\nmsgid ""\nmsgstr ""\n\n#: source2\nmsgid ""\nmsgstr ""\n'
+        )
         pofile = self.poparse(posource)
         assert len(pofile.units) == 2
         pofile.removeduplicates("keep")
         assert len(pofile.units) == 2
         # check we don't add msgidcomments
-        assert po.unquotefrompo(pofile.units[0].msgidcomments) == ""
-        assert po.unquotefrompo(pofile.units[1].msgidcomments) == ""
+        assert cpo.unquotefrompo(pofile.units[0].msgidcomments) == ""
+        assert cpo.unquotefrompo(pofile.units[1].msgidcomments) == ""
 
     def test_output_str_unicode(self):
         """checks that we can serialize pofile, unit content is in unicode"""
-        posource = u'''#: nb\nmsgid "Norwegian Bokm\xe5l"\nmsgstr ""\n'''
-        pofile = self.StoreClass(wStringIO.StringIO(posource.encode("UTF-8")), encoding="UTF-8")
+        posource = """#: nb\nmsgid "Norwegian Bokmål"\nmsgstr ""\n"""
+        pofile = self.StoreClass(BytesIO(posource.encode("UTF-8")), encoding="UTF-8")
         assert len(pofile.units) == 1
         print(bytes(pofile))
         thepo = pofile.units[0]
-#        assert bytes(pofile) == posource.encode("UTF-8")
+        #        assert bytes(pofile) == posource.encode("UTF-8")
         # extra test: what if we set the msgid to a unicode? this happens in prop2po etc
-        thepo.source = u"Norwegian Bokm\xe5l"
-#        assert str(thepo) == posource.encode("UTF-8")
+        thepo.source = "Norwegian Bokm\xe5l"
+        #        assert str(thepo) == posource.encode("UTF-8")
         # Now if we set the msgstr to Unicode
         # this is an escaped half character (1/2)
         halfstr = b"\xbd ...".decode("latin-1")
         thepo.target = halfstr
-#        assert halfstr in bytes(pofile).decode("UTF-8")
+        #        assert halfstr in bytes(pofile).decode("UTF-8")
         thepo.target = halfstr.encode("UTF-8")
-#        assert halfstr.encode("UTF-8") in bytes(pofile)
+
+    #        assert halfstr.encode("UTF-8") in bytes(pofile)
 
     def test_posections(self):
         """checks the content of all the expected sections of a PO message"""
@@ -177,7 +183,7 @@ class TestCPOFile(test_po.TestPOFile):
         pofile = self.poparse(posource)
         print(pofile)
         assert len(pofile.units) == 1
-        assert bytes(pofile).decode('utf-8') == posource
+        assert bytes(pofile).decode("utf-8") == posource
 
     def test_multiline_obsolete(self):
         """Tests for correct output of mulitline obsolete messages"""
@@ -188,7 +194,7 @@ class TestCPOFile(test_po.TestPOFile):
         assert len(pofile.units) == 1
         assert pofile.units[0].isobsolete()
         assert not pofile.units[0].istranslatable()
-        assert bytes(pofile).decode('utf-8') == posource
+        assert bytes(pofile).decode("utf-8") == posource
 
     def test_unassociated_comments(self):
         """tests behaviour of unassociated comments."""
@@ -196,4 +202,8 @@ class TestCPOFile(test_po.TestPOFile):
         oldfile = self.poparse(oldsource)
         print("serialize", bytes(oldfile))
         assert len(oldfile.units) == 1
-        assert "# old lonesome comment\nmsgid" in bytes(oldfile).decode('utf-8')
+        assert "# old lonesome comment\nmsgid" in bytes(oldfile).decode("utf-8")
+
+    @mark.xfail(reason="removal not working in cPO")
+    def test_remove(self):
+        super().test_remove()
