@@ -1037,6 +1037,18 @@ msgstr ""
 "\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\"
 "\\"
 """
+        assert self.poreflow(posource) == posource_wanted
+
+    def test_wrapping_cjk(self):
+        posource = r"""msgid ""
+msgstr "Content-Type: text/plain; charset=utf-8\n"
+
+msgid "test"
+msgstr ""
+"効率的なバグの報告はPostGISの開発を助ける本質的な方法です。最も効率的なバグ報"
+"告は、PostGIS開発者がそれを再現できるようにすることで、それの引き金となったス"
+"""
+        assert self.poreflow(posource) == posource
 
     def test_wrap_gettext(self):
         posource = r"""# Test
@@ -1052,8 +1064,8 @@ msgstr ""
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n"
-"%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
+"Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && "
+"n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Generator: Weblate 4.0.4\n"
 
 #: configuredialog.cpp:4580
@@ -1069,7 +1081,13 @@ msgid ""
 "under \"Manage Account\"."
 msgstr ""
 """
-        assert self.poreflow(posource) == posource
+        reflowed = self.poreflow(posource)
+        if reflowed == posource:
+            # Gettext 0.21.1 and newer
+            assert self.poreflow(posource) == posource
+        else:
+            # Gettext 0.21 and older
+            assert self.poreflow(posource) == posource.replace('"\n"n%10', 'n"\n"%10')
 
     def test_msgidcomments(self):
         posource = r"""
@@ -1123,6 +1141,29 @@ msgstr "texte"
     def test_invalid(self):
         posource = b"""
 msg
+"""
+        with raises(ValueError):
+            self.poparse(posource)
+
+    def test_wrapped_msgid(self):
+        posource = b"""
+#| msgid "some"
+#|"old text"
+msgid "text"
+msgstr "texte"
+"""
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        unit = pofile.units[0]
+        if not hasattr(pofile, "_gpo_memory_file"):
+            assert unit.prev_source == "someold text"
+        assert unit.source == "text"
+
+    def test_missing_plural(self):
+        posource = b"""
+msgid "text"
+msgid_plural "texts"
+msgstr "texte"
 """
         with raises(ValueError):
             self.poparse(posource)
