@@ -262,15 +262,36 @@ userItems.limit[\=0] = No items can be added.
         assert propunit.source == "No items can be added."
 
     def test_non_plurals(self):
-        propsource = r"""
-Ps[Pd]_unexpected = Test string
+        propsource = r"""Ps[Pd]_unexpected=Test string
+PP[]=Other
 """
         propfile = self.propparse(propsource)
 
-        assert len(propfile.units) == 1
+        assert len(propfile.units) == 2
         propunit = propfile.units[0]
         assert propunit.name == "Ps[Pd]_unexpected"
         assert propunit.source == "Test string"
+        propunit = propfile.units[1]
+        assert propunit.name == "PP[]"
+        assert propunit.source == "Other"
+        assert bytes(propfile).decode() == propsource
+
+    def test_encoding(self):
+        propsource = """test=Zkouška
+"""
+        propfile = self.propparse(propsource)
+        assert len(propfile.units) == 1
+        propunit = propfile.units[0]
+        assert propunit.name == "test"
+        assert propunit.source == "Zkouška"
+        assert bytes(propfile).decode() == propsource
+
+        propfile = self.propparse(propsource, encoding="iso-8859-1")
+        propfile.encoding = "iso-8859-1"
+        propunit = propfile.units[0]
+        assert bytes(propfile).decode() == propsource
+        propunit.source = "xZkouška"
+        assert bytes(propfile).decode() == "test=xZkou\\u0161ka\n"
 
 
 class TestProp(test_monolingual.TestMonolingualStore):
