@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -18,7 +17,6 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 import re
-import six
 
 
 def reduce_tree(f, parent_unit_node, unit_node, get_children, *state):
@@ -42,7 +40,9 @@ def reduce_tree(f, parent_unit_node, unit_node, get_children, *state):
 
     state = f(parent_unit_node, unit_node, *state)
     for child_unit_node in get_children(unit_node):
-        state = reduce_tree(f, unit_node, child_unit_node, get_children, *as_tuple(state))
+        state = reduce_tree(
+            f, unit_node, child_unit_node, get_children, *as_tuple(state)
+        )
     return state
 
 
@@ -60,7 +60,7 @@ def compose_mappings(left, right):
     return result_map
 
 
-tag_pattern = re.compile(r'({(?P<namespace>(\w|[-:./])*)})?(?P<tag>(\w|[-])*)')
+tag_pattern = re.compile(r"({(?P<namespace>(\w|[-:./])*)})?(?P<tag>(\w|[-])*)")
 
 
 def parse_tag(full_tag):
@@ -76,9 +76,9 @@ def parse_tag(full_tag):
         ret = []
         for k in ("namespace", "tag"):
             value = match.groupdict()[k] or ""
-            if not isinstance(value, six.text_type):
-                value = six.text_type(value, encoding="utf-8")
+            if not isinstance(value, str):
+                value = str(value, encoding="utf-8")
             ret.append(value)
         return ret[0], ret[1]
     else:
-        raise Exception('Passed an invalid tag')
+        raise Exception("Passed an invalid tag")
