@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Mozilla Corporation, Zuza Software Foundation
 #
@@ -27,7 +26,6 @@ from translate.storage import po
 
 
 class phppo2pypo:
-
     def convertstore(self, inputstore):
         """Converts a given .po file (PHP Format) to a Python format .po file,
         the difference being how variable substitutions work.  PHP uses a %1$s
@@ -57,8 +55,9 @@ class phppo2pypo:
         unit.target = self.convertstrings(unit.target)
         return unit
 
-    def convertstring(self, input):
-        return re.sub(r'%(\d)\$s', lambda x: "{%d}" % (int(x.group(1)) - 1), input)
+    @staticmethod
+    def convertstring(input):
+        return re.sub(r"%(\d)\$s", lambda x: "{%d}" % (int(x.group(1)) - 1), input)
 
     def convertstrings(self, input):
         if isinstance(input, multistring):
@@ -68,7 +67,9 @@ class phppo2pypo:
         else:
             return self.convertstring(input)
         for index, string in enumerate(strings):
-            strings[index] = re.sub(r'%(\d)\$s', lambda x: "{%d}" % (int(x.group(1)) - 1), string)
+            strings[index] = re.sub(
+                r"%(\d)\$s", lambda x: "{%d}" % (int(x.group(1)) - 1), string
+            )
         return multistring(strings)
 
 
@@ -97,5 +98,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
